==> vue-hooks-1.1.1.tgz: package/lib/use-context/inject.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __markAsModule = (target) => __defProp(target, "__esModule", { value: true });
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __export = (target, all) => {
  __markAsModule(target);
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __reExport = (target, module2, desc) => {
  if (module2 && typeof module2 === "object" || typeof module2 === "function") {
    for (let key of __getOwnPropNames(module2))
      if (!__hasOwnProp.call(target, key) && key !== "default")
        __defProp(target, key, { get: () => module2[key], enumerable: !(desc = __getOwnPropDesc(module2, key)) || desc.enumerable });
  }
  return target;
};
var __toModule = (module2) => {
  return __reExport(__markAsModule(__defProp(module2 != null ? __create(__getProtoOf(module2)) : {}, "default", module2 && module2.__esModule && "default" in module2 ? { get: () => module2.default, enumerable: true } : { value: module2, enumerable: true })), module2);
};
__export(exports, {
  useProvider: () => useProvider
});
var import_vue = __toModule(require("vue"));
const useProvider = (key) => {
  const context = (0, import_vue.inject)(key, null);
  if (context) {
    const instance = (0, import_vue.getCurrentInstance)();
    const _a = context, { link, unlink, internalChildren } = _a, rest = __objRest(_a, ["link", "unlink", "internalChildren"]);
    link(instance);
    (0, import_vue.onUnmounted)(() => unlink(instance));
    const idx = (0, import_vue.computed)(() => internalChildren.indexOf(instance));
    return {
      context: rest,
      idx: idx.value
    };
  }
  return {
    context: null,
    idx: -1
  };
};

==> vue-hooks-1.3.0.tgz: package/lib/use-context/inject.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var stdin_exports = {};
__export(stdin_exports, {
  useProvider: () => useProvider
});
module.exports = __toCommonJS(stdin_exports);
var import_vue = require("vue");
const useProvider = (key) => {
  const context = (0, import_vue.inject)(key, null);
  if (context) {
    const instance = (0, import_vue.getCurrentInstance)();
    const _a = context, { link, unlink, internalChildren } = _a, rest = __objRest(_a, ["link", "unlink", "internalChildren"]);
    link(instance);
    (0, import_vue.onUnmounted)(() => unlink(instance));
    const idx = (0, import_vue.computed)(() => internalChildren.indexOf(instance));
    return {
      context: rest,
      idx: idx.value
    };
  }
  return {
    context: null,
    idx: -1
  };
};
